<?php
/**
* Enqueue scripts and styles
*
* @package GridBit WordPress Theme
* @copyright Copyright (C) 2021 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridbit_scripts() {
    wp_enqueue_style('gridbit-maincss', get_stylesheet_uri(), array(), NULL);
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), NULL );
    wp_enqueue_style('gridbit-webfont', '//fonts.googleapis.com/css?family=Source+Serif+Pro:400,700&amp;display=swap', array(), NULL);

    $gridbit_fitvids_active = FALSE;
    if ( gridbit_is_fitvids_active() ) {
        $gridbit_fitvids_active = TRUE;
    }
    if ( $gridbit_fitvids_active ) {
        wp_enqueue_script('fitvids', get_template_directory_uri() .'/assets/js/jquery.fitvids.min.js', array( 'jquery' ), NULL, true);
    }

    $gridbit_backtotop_active = FALSE;
    if ( gridbit_is_backtotop_active() ) {
        $gridbit_backtotop_active = TRUE;
    }

    $gridbit_primary_menu_active = FALSE;
    if ( gridbit_is_primary_menu_active() ) {
        $gridbit_primary_menu_active = TRUE;
    }
    $gridbit_secondary_menu_active = FALSE;
    if ( gridbit_is_secondary_menu_active() ) {
        $gridbit_secondary_menu_active = TRUE;
    }

    wp_enqueue_script('gridbit-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), NULL, true );
    wp_enqueue_script('gridbit-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), NULL, true );
    wp_enqueue_script('gridbit-customjs', get_template_directory_uri() .'/assets/js/custom.js', array( 'jquery', 'imagesloaded' ), NULL, true);

    wp_localize_script( 'gridbit-customjs', 'gridbit_ajax_object',
        array(
            'ajaxurl' => esc_url_raw( admin_url( 'admin-ajax.php' ) ),
            'primary_menu_active' => $gridbit_primary_menu_active,
            'secondary_menu_active' => $gridbit_secondary_menu_active,
            'fitvids_active' => $gridbit_fitvids_active,
            'backtotop_active' => $gridbit_backtotop_active,
        )
    );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    wp_enqueue_script('gridbit-html5shiv-js', get_template_directory_uri() .'/assets/js/html5shiv.js', array('jquery'), NULL, true);

    wp_localize_script('gridbit-html5shiv-js','gridbit_custom_script_vars',array(
        'elements_name' => esc_html__('abbr article aside audio bdi canvas data datalist details dialog figcaption figure footer header hgroup main mark meter nav output picture progress section summary template time video', 'gridbit'),
    ));
}
add_action( 'wp_enqueue_scripts', 'gridbit_scripts' );

/**
 * Enqueue IE compatible scripts and styles.
 */
function gridbit_ie_scripts() {
    wp_enqueue_script( 'respond', get_template_directory_uri(). '/assets/js/respond.min.js', array(), NULL, false );
    wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'gridbit_ie_scripts' );

/**
 * Enqueue styles for the block-based editor.
 */
function gridbit_block_editor_styles() {
    wp_enqueue_style( 'gridbit-block-editor-style', get_template_directory_uri() . '/assets/css/editor-blocks.css', array(), NULL );
}
add_action( 'enqueue_block_editor_assets', 'gridbit_block_editor_styles' );

/**
 * Enqueue customizer styles.
 */
function gridbit_enqueue_customizer_styles() {
    wp_enqueue_style( 'gridbit-customizer-styles', get_template_directory_uri() . '/inc/admin/css/customizer-style.css', array(), NULL );
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), NULL );
}
add_action( 'customize_controls_enqueue_scripts', 'gridbit_enqueue_customizer_styles' );